@@ -85,8 +85,6 @@ Desc <- function(){
 
 Select <- function(){
 
-  requireNamespace("DescTools")
-
   sel <- getActiveDocumentContext()$selection[[1]]$text
   if(sel != "") {
     if(sel == "pch") {
@@ -98,7 +96,7 @@ Select <- function(){
         rstudioapi::insertText(gettextf("col=c(%s)", paste(shQuote(txt), collapse=", ")))
 
     } else if(sel %in% c("fn", "file")) {
-      txt <- eval(parse(text="FileOpenCmd(fmt='%path%%fname%.%ext%')"))
+      txt <- eval(parse(text="FileOpenDlg(fmt='%path%%fname%.%ext%')"))
       if(txt != "")
         rstudioapi::insertText(gettextf("%s=%s", sel, shQuote(txt)))
 
@@ -122,8 +120,6 @@ Select <- function(){
 
 BuildModel <- function(){
 
-  requireNamespace("DescTools")
-
   sel <- getActiveDocumentContext()$selection[[1]]$text
   if(sel != ""){
     txt <- eval(parse(text=gettextf("ModelDlg(%s)", sel)))
@@ -140,7 +136,10 @@ BuildModel <- function(){
 Plot <- function(){
   sel <- getActiveDocumentContext()$selection[[1]]$text
   if(sel != "") {
-    rstudioapi::sendToConsole(gettextf("plot(%s)", sel), focus = FALSE)
+    if(sel=="mar")
+      rstudioapi::sendToConsole("PlotMar()", focus = FALSE)
+    else
+      rstudioapi::sendToConsole(gettextf("plot(%s)", sel), focus = FALSE)
   } else {
     cat("No selection!\n")
   }
@@ -159,6 +158,7 @@ PlotD <- function(){
   }
 }
 
+
 Head <- function(){
   sel <- getActiveDocumentContext()$selection[[1]]$text
   if(sel != ""){
@@ -170,35 +170,38 @@ Head <- function(){
 }
 
 
-Info <- function(x){
-
-  class_x <- strwrap(paste(class(x), collapse=", "),
-                     width= getOption("width") - nchar("  Class(es):   "))
-  class_x[-1] <- paste(strrep(" ", nchar("  Class(es):  ")), class_x[-1])
-
-  cat(gettextf("Properties -------- \n  Object:      %s\n  TypeOf:      %s\n  Class(es):   %s\n  Mode:        %s\n  Dimension:   %s\n  Length:      %s\n  Size:        %s\n  Attributes:  ",
-               deparse(substitute(x)), typeof(x),
-               paste(class_x, collapse="\n"),
-               mode(x),
-               ifelse(is.null(dim(x)), "NULL", toString(dim(x))), length(x), capture.output(object.size(x))))
-  if(!is.null(attributes(x))) {
-    cat("\n")
-    opt <- options(width=getOption("width") - 4)
-    cat(paste("    ", capture.output(attributes(x))), sep="\n")
-    options(opt)
-  } else
-    cat("none\n\n")
-}
 
 
+Info <- function(){
 
-Class <- function(){
+  .Info <- function(x){
+
+    class_x <- strwrap(paste(class(x), collapse=", "),
+                       width= getOption("width") - nchar("  Class(es):   "))
+    class_x[-1] <- paste(strrep(" ", nchar("  Class(es):  ")), class_x[-1])
+
+    cat(gettextf("Properties -------- \n  Object:      %s\n  TypeOf:      %s\n  Class(es):   %s\n  Mode:        %s\n  Dimension:   %s\n  Length:      %s\n  Size:        %s\n  Attributes:  ",
+                 deparse(substitute(x)), typeof(x),
+                 paste(class_x, collapse="\n"),
+                 mode(x),
+                 ifelse(is.null(dim(x)), "NULL", toString(dim(x))), length(x),
+                 paste0(Format(as.numeric(object.size(x)), fmt="engabb",  digits=1), "B")
+                 ))
+    if(!is.null(attributes(x))) {
+      cat("\n")
+      opt <- options(width=getOption("width") - 4)
+      cat(paste("    ", capture.output(attributes(x))), sep="\n")
+      options(opt)
+    } else
+      cat("none\n\n")
+  }
 
   sel <- getActiveDocumentContext()$selection[[1]]$text
 
   if(sel != ""){
-    # val(parse(text = gettextf("DescToolsAddIns::Info(%s)", sel)))
-    rstudioapi::sendToConsole(gettextf("DescToolsAddIns::Info(%s)", sel), execute = TRUE, focus = FALSE)
+#    rstudioapi::sendToConsole(gettextf(".Info(%s)", sel), execute = TRUE, focus = FALSE)
+    eval(parse(text = gettextf(".Info(%s)", sel)))
+
   } else {
     cat("No selection!\n")
   }
@@ -219,20 +222,81 @@ Some <- function(){
 
 }
 
-Save <- function(){
-  sel <- getActiveDocumentContext()$selection[[1]]$text
 
-  if(sel != "") {
-    f <- tclvalue(eval(parse(text=gettextf("tkgetSaveFile(initialfile='%s.rda', title='Save a file...')", sel))))
-    if(f != "")
-      rstudioapi::sendToConsole(gettextf("save(x=%s, file='%s')", sel, f), focus = FALSE)
+# Save <- function(){
+#   sel <- getActiveDocumentContext()$selection[[1]]$text
+#
+#   if(sel != "") {
+#     f <- tclvalue(eval(parse(text=gettextf("tkgetSaveFile(initialfile='%s.rda', title='Save a file...')", sel))))
+#     if(f != "")
+#       rstudioapi::sendToConsole(gettextf("save(x=%s, file='%s')", sel, f), focus = FALSE)
+#   } else {
+#     cat("No selection!\n")
+#   }
+#
+# }
+
+
+FileOpen <- function(){
+
+  txt <- eval(parse(text="FileOpenDlg(fmt=NULL)"))
+  if(txt != "") {
+    rstudioapi::insertText(txt)
+  }
+}
+
+
+
+FileImport <- function(){
+
+  txt <- eval(parse(text="FileImportDlg()"))
+  if(txt != "") {
+    rstudioapi::insertText(txt)
+  }
+}
+
+
+FileSaveAs <- function() {
+
+  sel <- getActiveDocumentContext()$selection[[1]]$text
+  if (sel != "") {
+
+    f <- tclvalue(eval(parse(text = gettextf("tkgetSaveFile(initialfile='%s', title='Save a file...', filetypes = '{{R (binary)} {.rda}} {{Comma separated} {.csv}} {Text {.txt}} {{Excel} {*.xlsx} }', defaultextension = '.rda')",
+                                             sel))))
+    if (f != "") {
+      ext <- tools::file_ext(f)
+
+      if(ext=="rda"){
+        rstudioapi::sendToConsole(gettextf("save(x=%s, file='%s')",
+                                           sel, f), focus = FALSE)
+      } else if(ext=="csv"){
+        rstudioapi::sendToConsole(gettextf("write.csv(x=%s, file='%s')",
+                                           sel, f), focus = FALSE)
+
+      } else if(ext=="xlsx"){
+
+        requireNamespace("writexl")
+        rstudioapi::sendToConsole(gettextf("writexl::write_xlsx(x=%s, path='%s')",
+                                           sel, f), focus = FALSE)
+
+      } else if(ext=="txt"){
+        if(eval(parse(text = gettextf("inherits(%s, 'character')", sel)))){
+          rstudioapi::sendToConsole(gettextf("writeLines(text=%s, con='%s')", sel, f), focus = FALSE)
+
+        } else {
+          rstudioapi::sendToConsole(gettextf("dput(x=%s, file='%s')", sel, f), focus = FALSE)
+
+        }
+      }
+    }
+
   } else {
     cat("No selection!\n")
   }
-
 }
 
 
+
 XLView <- function(){
 
   requireNamespace("DescTools")
@@ -257,17 +321,6 @@ IntView <- function(){
 
 
 
-FileOpen <- function(){
-
-  requireNamespace("DescTools")
-
-  txt <- eval(parse(text="FileOpenCmd(fmt=NULL)"))
-  if(txt != "") {
-    rstudioapi::insertText(txt)
-  }
-}
-
-
 FlipBackSlash <- function() {
   txt <- getActiveDocumentContext()$selection[[1]]$text
   if(txt != "") {
